------------------------ COPYRIGHT STATEMENT ----------------------------
--
-- Licensed Materials - Property of IBM
-- 5724-C40
-- (C) Copyright IBM Corp. 2003.  All Rights Reserved.
--
-- US Government Users Restricted Rights - Use, duplication or
-- disclosure restricted by GSA ADP Schedule Contract with
-- IBM Corp.
--
------------------------END OF COPYRIGHT STATEMENT -----------------------

--------------------------------------------------------------------------
--  CMVC Location:  src/tedw_apps/dyk/cdw/dml/dyk_cdw_data.sql, etl.target, slm1.2.1.fp1
--  Version:        1.2
--  Last Modified:  8/8/03
--------------------------------------------------------------------------

--
-- Insert records into CDW extract_control table to support
-- incremental extracts for TSLA ETLs.
--
declare global temporary table extract_control (
       ExtCtl_Source        VARCHAR(120) NOT NULL,
       ExtCtl_Target        VARCHAR(120) NOT NULL,
       ExtCtl_From_RawSeq   CHAR(10) FOR BIT DATA,
       ExtCtl_To_RawSeq     CHAR(10) FOR BIT DATA,
       ExtCtl_From_IntSeq   BIGINT,
       ExtCtl_To_IntSeq     BIGINT,
       ExtCtl_From_DtTm     TIMESTAMP NOT NULL,
       ExtCtl_To_DtTm       TIMESTAMP NOT NULL
)
with replace on commit preserve rows not logged
;

--
-- Record for managing incremental extract of measurement records. 
--
INSERT INTO
   session.EXTRACT_CONTROL
VALUES (
   'TWG.MSMT',
   'DYK.STAGE_MSMT',
   x'00000000000000000000',
   x'00000000000000000000',
   0,
   0,
   CURRENT TIMESTAMP - CURRENT TIMEZONE,
   CURRENT TIMESTAMP - CURRENT TIMEZONE)
;

--
-- Record for managing incremental extract of component records. 
--
INSERT INTO
   session.EXTRACT_CONTROL
VALUES (
   'TWG.CUR_COMP',
   'DYK.COMP',
   x'00000000000000000000',
   x'00000000000000000000',
   -1,
   -1,
   CURRENT TIMESTAMP - CURRENT TIMEZONE,
   CURRENT TIMESTAMP - CURRENT TIMEZONE)
;

--
-- Record for managing incremental extract of component relationship records. 
--
INSERT INTO
   session.EXTRACT_CONTROL
VALUES (
   'TWG.CUR_COMPRELN',
   'DYK.COMPRELN',
   x'00000000000000000000',
   x'00000000000000000000',
   0,
   0,
   CURRENT TIMESTAMP - CURRENT TIMEZONE,
   CURRENT TIMESTAMP - CURRENT TIMEZONE)
;

--
-- Record for managing incremental extract of component attribute records. 
--
INSERT INTO
   session.EXTRACT_CONTROL
VALUES (
   'TWG.CUR_COMPATTR',
   'DYK.COMPATTR',
   x'00000000000000000000',
   x'00000000000000000000',
   0,
   0,
   CURRENT TIMESTAMP - CURRENT TIMEZONE,
   CURRENT TIMESTAMP - CURRENT TIMEZONE)
;

--
-- Insert into CDW extract-control table if the records do not already exist.
--
insert into twg.extract_control
select * from session.extract_control s
where not exists (
        select 1 from
        twg.extract_control t where
        t.extctl_source = s.extctl_source and
        t.extctl_target = s.extctl_target
);
