------------------------ COPYRIGHT STATEMENT ----------------------------
--
-- Licensed Materials - Property of IBM
-- 5724-C40
-- (C) Copyright IBM Corp. 2003.  All Rights Reserved.
--
-- US Government Users Restricted Rights - Use, duplication or
-- disclosure restricted by GSA ADP Schedule Contract with
-- IBM Corp.
--
------------------------END OF COPYRIGHT STATEMENT -----------------------

--------------------------------------------------------------------------
--  CMVC Location:  src/tedw_apps/dyk/etl/sql/DYK_m05_s030_Update_Extract_Control.db2, etl.target, slm1.2.1.fp1
--  Version:        1.1
--  Last Modified:  7/18/03
--------------------------------------------------------------------------

--
-- Create temporary calibration table.
--
--#EXECUTE_AT_TARGET
--#IGNORE_ERROR
drop table mm.calibrate;

--#EXECUTE_AT_TARGET
create table mm.calibrate (
    rec_id    integer
);

--
-- Create temporary table for CDW extract control update.
--
--#IGNORE_ERROR
drop table dyk.ext_upd;

create table dyk.ext_upd (
    start_range  integer not null,
    end_range    integer not null
);


--
-- Process/Update the extract control record for COMP data.
--

--
-- Find min COMP ID of records moved on this ETL run.
--      
--#EXECUTE_AT_TARGET
insert into mm.calibrate (rec_id)
    select
      min(c.comp_id)
    from
      mm.comp c
    where
      c.comp_id > (select coalesce(max(end_range), -1) from mm.extract_log where
      ext_target = 'MM.COMP');

--
-- Find max COMP ID of records moved on this ETL run.
--      
--#EXECUTE_AT_TARGET
insert into mm.calibrate (rec_id)
    select
      max(c.comp_id)
    from
      mm.comp c
    where
      c.comp_id > (select coalesce(max(end_range), -1) from mm.extract_log where
      ext_target = 'MM.COMP');
      
--
-- Add a row to the extract log reflecting the COMP data already stored in the datamart.
--
--#EXECUTE_AT_TARGET
insert into mm.extract_log (ext_target, complete_tm, start_range, end_range)
    select
      'MM.COMP',
      current timestamp - current timezone, 
      coalesce(cal.min_comp_id, el.start_range, -1),
      coalesce(cal.max_comp_id, el.end_range, -1)
    from 
      (select min(rec_id) as min_comp_id, max(rec_id) as max_comp_id from mm.calibrate) as cal,
      (select max(start_range) as start_range, max(end_range) as end_range from mm.extract_log where
      ext_target = 'MM.COMP') as el;

--
-- Insert COMP values into temporary extract table.
--
--#INSERT_INTO_SOURCE
insert into dyk.ext_upd 
    select
        el.start_range,
        el.end_range
    from
        mm.extract_log el
    where
        complete_tm = (select max(complete_tm) from mm.extract_log where  
	ext_target = 'MM.COMP');

--
-- Update the COMP extract control record in the CDW.
--
update
    twg.extract_control
set
    (extctl_to_intseq, extctl_from_intseq) = (select end_range, start_range from dyk.ext_upd)
where
    extctl_source = 'TWG.CUR_COMP' and
    extctl_target = 'DYK.COMP';


--
-- Clear staging tables to prepare for next update.
--

--#EXECUTE_AT_TARGET
delete from mm.calibrate;

delete from dyk.ext_upd;


--
-- Process/Update the extract control record for COMPATTR data.
--

--
-- Find min COMPATTR ID of records moved on this ETL run.
--      
--#EXECUTE_AT_TARGET
insert into mm.calibrate (rec_id)
    select
      min(c.compattr_id)
    from
      mm.compattr c
    where
      c.compattr_id > (select coalesce(max(end_range), 0) from mm.extract_log where
      ext_target = 'MM.COMPATTR');

--
-- Find max COMPATTR ID of records moved on this ETL run.
--      
--#EXECUTE_AT_TARGET
insert into mm.calibrate (rec_id)
    select
      max(c.compattr_id)
    from
      mm.compattr c
    where
      c.compattr_id > (select coalesce(max(end_range), 0) from mm.extract_log where
      ext_target = 'MM.COMPATTR');
      
--
-- Add a row to the extract log reflecting the COMPATTR data already stored in the datamart.
--
--#EXECUTE_AT_TARGET
insert into mm.extract_log (ext_target, complete_tm, start_range, end_range)
    select
      'MM.COMPATTR',
      current timestamp - current timezone,
      coalesce(cal.min_compattr_id, el.start_range, 0),
      coalesce(cal.max_compattr_id, el.end_range, 0)
    from 
      (select min(rec_id) as min_compattr_id, max(rec_id) as max_compattr_id from mm.calibrate where) as cal,
      (select max(start_range) as start_range, max(end_range) as end_range from mm.extract_log where
      ext_target = 'MM.COMPATTR') as el;

--
-- Insert COMPATTR values into temporary extract table.
--
--#INSERT_INTO_SOURCE
insert into dyk.ext_upd 
    select
        el.start_range,
        el.end_range
    from
        mm.extract_log el
    where
        complete_tm = (select max(complete_tm) from mm.extract_log where 
	ext_target = 'MM.COMPATTR');

--
-- Update the COMPATTR extract control record in the CDW.
--
update
    twg.extract_control
set
    (extctl_to_intseq, extctl_from_intseq) = (select end_range, start_range from dyk.ext_upd)
where
    extctl_source = 'TWG.CUR_COMPATTR' and
    extctl_target = 'DYK.COMPATTR';


--
-- Clear staging tables to prepare for final update.
--

--#EXECUTE_AT_TARGET
delete from mm.calibrate;

delete from dyk.ext_upd;


--
-- Process/Update the extract control record for COMPRELN data.
--

--
-- Find min COMPRELN ID of records moved on this ETL run.
--      
--#EXECUTE_AT_TARGET
insert into mm.calibrate (rec_id)
    select
      min(c.compreln_id)
    from
      mm.compreln c
    where
      c.compreln_id > (select coalesce(max(end_range), 0) from mm.extract_log where
      ext_target = 'MM.COMPRELN');

--
-- Find max COMPRELN ID of records moved on this ETL run.
--      
--#EXECUTE_AT_TARGET
insert into mm.calibrate (rec_id)
    select
      max(c.compreln_id)
    from
      mm.compreln c
    where
      c.compreln_id > (select coalesce(max(end_range), 0) from mm.extract_log where
      ext_target = 'MM.COMPRELN');
      
--
-- Add a row to the extract log reflecting the COMPRELN data already stored in the datamart.
--
--#EXECUTE_AT_TARGET
insert into mm.extract_log (ext_target, complete_tm, start_range, end_range)
    select
      'MM.COMPRELN',
      current timestamp - current timezone,
      coalesce(cal.min_compreln_id, el.start_range, 0),
      coalesce(cal.max_compreln_id, el.end_range, 0)
    from 
      (select min(rec_id) as min_compreln_id, max(rec_id) as max_compreln_id from mm.calibrate) as cal,
      (select max(start_range) as start_range, max(end_range) as end_range from mm.extract_log where
      ext_target = 'MM.COMPRELN') as el;

--
-- Insert COMPRELN values into temporary extract table.
--
--#INSERT_INTO_SOURCE
insert into dyk.ext_upd 
    select
        el.start_range,
        el.end_range
    from
        mm.extract_log el
    where
        complete_tm = (select max(complete_tm) from mm.extract_log where  
	ext_target = 'MM.COMPRELN');

--
-- Update the COMPRELN extract control record in the current CDW being processed.
--
update
    twg.extract_control
set
    (extctl_to_intseq, extctl_from_intseq) = (select end_range, start_range from dyk.ext_upd)
where
    extctl_source = 'TWG.CUR_COMPRELN' and
    extctl_target = 'DYK.COMPRELN';
    

